@@ -443,6 +443,12 @@ class ViewRepresentation(OperatorPlatform, ABC):
     def extend(self, ops, *, partition_by=None, order_by=None, reverse=None):
         if (ops is None) or (len(ops) < 1):
             return self
+        if isinstance(partition_by, str):
+            partition_by = [partition_by]
+        if isinstance(order_by, str):
+            order_by = [order_by]
+        if isinstance(reverse, str):
+            reverse = [reverse]
         parsed_ops = data_algebra.expr_parse.parse_assignments_in_context(ops, self)
         return self.extend_parsed(
             parsed_ops=parsed_ops,
@@ -464,6 +470,8 @@ class ViewRepresentation(OperatorPlatform, ABC):
         return ProjectNode(source=self, parsed_ops=parsed_ops, group_by=group_by)
 
     def project(self, ops=None, *, group_by=None):
+        if isinstance(group_by, str):
+            group_by = [group_by]
         if group_by is None:
             group_by = []
         if ((ops is None) or (len(ops) < 1)) and (len(group_by) < 1):
@@ -481,6 +489,9 @@ class ViewRepresentation(OperatorPlatform, ABC):
         :return: ops describing join
         """
         assert isinstance(b, ViewRepresentation)
+        if isinstance(by, str):
+            by = [by]
+        assert isinstance(jointype, str)
         if self.is_trivial_when_intermediate():
             return self.sources[0].natural_join(b, by=by, jointype=jointype)
         return NaturalJoinNode(
@@ -495,6 +506,9 @@ class ViewRepresentation(OperatorPlatform, ABC):
         if b is None:
             return self
         assert isinstance(b, ViewRepresentation)
+        assert isinstance(id_column, (str, type(None)))
+        assert isinstance(a_name, str)
+        assert isinstance(b_name, str)
         if self.is_trivial_when_intermediate():
             return self.sources[0].concat_rows(
                 b, id_column=id_column, a_name=a_name, b_name=b_name
@@ -513,6 +527,15 @@ class ViewRepresentation(OperatorPlatform, ABC):
     def select_rows(self, expr):
         if expr is None:
             return self
+        if isinstance(expr, (list, tuple)):
+            # convert lists to and expressions
+            assert all([isinstance(vi, str) for vi in expr])
+            if len(expr) < 1:
+                return self
+            elif len(expr) == 1:
+                expr = expr[0]
+            else:
+                expr = ' & '.join(['(' + vi + ')' for vi in expr])
         assert isinstance(expr, (str, data_algebra.expr_rep.PreTerm))
         if self.is_trivial_when_intermediate():
             return self.sources[0].select_rows(expr)
@@ -529,6 +552,8 @@ class ViewRepresentation(OperatorPlatform, ABC):
         return self.select_rows_parsed(parsed_expr=ops)
 
     def drop_columns(self, column_deletions):
+        if isinstance(column_deletions, str):
+            column_deletions = [column_deletions]
         if (column_deletions is None) or (len(column_deletions) < 1):
             return self
         if self.is_trivial_when_intermediate():
@@ -536,6 +561,8 @@ class ViewRepresentation(OperatorPlatform, ABC):
         return DropColumnsNode(source=self, column_deletions=column_deletions)
 
     def select_columns(self, columns):
+        if isinstance(columns, str):
+            columns = [columns]
         if (columns is None) or (len(columns) < 1):
             raise ValueError("must select at least one column")
         if columns == self.column_names:
@@ -551,24 +578,29 @@ class ViewRepresentation(OperatorPlatform, ABC):
     def rename_columns(self, column_remapping):
         if (column_remapping is None) or (len(column_remapping) < 1):
             return self
+        assert isinstance(column_remapping, dict)
         if self.is_trivial_when_intermediate():
             return self.sources[0].rename_columns(column_remapping)
         return RenameColumnsNode(source=self, column_remapping=column_remapping)
 
     def order_rows(self, columns, *, reverse=None, limit=None):
+        if isinstance(columns, str):
+            columns = [columns]
+        if isinstance(reverse, str):
+            reverse = [reverse]
         if ((columns is None) or (len(columns) < 1)) and (limit is None):
             return self
         if self.is_trivial_when_intermediate():
             return self.sources[0].order_rows(columns, reverse=reverse, limit=limit)
         return OrderRowsNode(source=self, columns=columns, reverse=reverse, limit=limit)
 
-    def convert_records(self, record_map, *, temp_namer=None):
+    def convert_records(self, record_map):
         if record_map is None:
             return self
         if self.is_trivial_when_intermediate():
-            return self.sources[0].convert_records(record_map, temp_namer=temp_namer)
+            return self.sources[0].convert_records(record_map)
         return ConvertRecordsNode(
-            source=self, record_map=record_map, temp_namer=temp_namer
+            source=self, record_map=record_map
         )
 
 
@@ -768,6 +800,7 @@ def describe_table(
     row_limit: typing.Optional[int] = 7,
     keep_sample=True,
     keep_all=False,
+    guess_column_types=True,
 ) -> TableDescription:
     """
     :param d: pandas table to describe
@@ -778,13 +811,15 @@ def describe_table(
     :param row_limit: how many rows to sample
     :param keep_sample: logical, if True retain head of table
     :param keep_all: logical, if True retain all of table
+    :param guess_column_types: logical, if True try to infer column types
     :return: TableDescription
     """
     assert not isinstance(d, OperatorPlatform)
     assert not isinstance(d, ViewRepresentation)
     column_names = [c for c in d.columns]
-    if column_types is None:
-        column_types = data_algebra.util.guess_column_types(d)
+    if (column_types is None) or (len(column_types) < 1):
+        if guess_column_types:
+            column_types = data_algebra.util.guess_column_types(d)
     head = None
     nrows = d.shape[0]
     if keep_all:
@@ -1847,10 +1882,9 @@ class ConcatRowsNode(ViewRepresentation):
 
 
 class ConvertRecordsNode(ViewRepresentation):
-    def __init__(self, *, source, record_map, temp_namer=None):
+    def __init__(self, *, source, record_map):
         sources = [source]
         self.record_map = record_map
-        self.temp_namer = temp_namer
         unknown = set(self.record_map.columns_needed) - set(source.column_names)
         if len(unknown) > 0:
             raise ValueError("missing required columns: " + str(unknown))
